@@ -83,7 +83,7 @@ Sv_RegisterGdbmStore(void)
  *
  *-----------------------------------------------------------------------------
  */
-static ClientData
+static void *
 ps_gdbm_open(
     const char *path)
 {
@@ -116,7 +116,7 @@ ps_gdbm_open(
  */
 static int
 ps_gdbm_close(
-    ClientData handle)
+    void *handle)
 {
     gdbm_close((GDBM_FILE)handle);
 
@@ -141,10 +141,10 @@ ps_gdbm_close(
  */
 static int
 ps_gdbm_get(
-     ClientData handle,
+     void *handle,
      const char   *key,
      char **dataptrptr,
-     size_t    *lenptr)
+     Tcl_Size *lenptr)
 {
     GDBM_FILE dbf = (GDBM_FILE)handle;
     datum drec, dkey;
@@ -181,10 +181,10 @@ ps_gdbm_get(
  */
 static int
 ps_gdbm_first(
-    ClientData  handle,
+    void *handle,
     char   **keyptrptr,
     char  **dataptrptr,
-    size_t     *lenptr)
+    Tcl_Size *lenptr)
 {
     GDBM_FILE dbf = (GDBM_FILE)handle;
     datum drec, dkey;
@@ -222,10 +222,10 @@ ps_gdbm_first(
  *-----------------------------------------------------------------------------
  */
 static int ps_gdbm_next(
-    ClientData  handle,
+    void *handle,
     char   **keyptrptr,
     char  **dataptrptr,
-    size_t     *lenptr)
+    Tcl_Size *lenptr)
 {
     GDBM_FILE dbf = (GDBM_FILE)handle;
     datum drec, dkey, dnext;
@@ -270,10 +270,10 @@ static int ps_gdbm_next(
  */
 static int
 ps_gdbm_put(
-    ClientData handle,
+    void *handle,
     const char   *key,
     char     *dataptr,
-    size_t        len)
+    Tcl_Size len)
 {
     GDBM_FILE dbf = (GDBM_FILE)handle;
     datum drec, dkey;
@@ -312,7 +312,7 @@ ps_gdbm_put(
  */
 static int
 ps_gdbm_delete(
-    ClientData handle,
+    void *handle,
     const char   *key)
 {
     GDBM_FILE dbf = (GDBM_FILE)handle;
@@ -347,10 +347,9 @@ ps_gdbm_delete(
  */
 static void
 ps_gdbm_free(
-    ClientData handle,
+    TCL_UNUSED(void *),
     void        *data)
 {
-    (void)handle;
     free(data);
 }
 
@@ -372,9 +371,8 @@ ps_gdbm_free(
  */
 static const char*
 ps_gdbm_geterr(
-    ClientData handle)
+    TCL_UNUSED(void *))
 {
-    (void)handle;
     /*
      * The problem with gdbm interface is that it uses the global
      * gdbm_errno variable which is not per-thread nor mutex
